==> linuxconf-tools-1.1.src.tar.gz: linuxconf-tools-1.1/projetx/pdiff.cc <==
/* Spcification: programme / pdiff

	pdiff permet d'appliquer la commande diff entre deux fichiers
	quelquoncques ou deux versions d'une mme fichier. Il localise
	les fichiers soit localement ou dans l'archive (/kit/ombre) et
	excute la commande diff avec les arguments corrigs.

	Comparaison entre la version locale et le rfrence:

		pdiff [options de diff] fichier

	Comparaison entre deux fichiers:

		pdiff [options de diff] fichier1 fichier2
*/
#include <stdio.h>
#include <assert.h>
#include <stdlib.h>
#include <string.h>
#include <misc.h>
#include "projet.h"

static void near usage()
{
	fprintf (stderr,"pdiff [options de diff] fichier1 fichier2\n");
	fprintf (stderr,"pdiff [options de diff] fichier\n");
}

/*
	Dtermine le path rel d'un fichier dans l'archive
*/
static void near pdiff_rpath (
	const char *fname,
	char *rpath,
	USERINFO *user)
{
	int ret = -1;
	MAKEFILE mkf ("makefile.dat",1,"",user);
	if (mkf.isok()){
		MAKEFILE_FILE *file = mkf.locate(fname);
		if (file != NULL){
			file->getombpath (user,rpath);
			ret = 0;
		}
	}
	if (ret == -1) exit (-1);
}


int main (int argc, char *argv[])
{
	int ret = -1;
	if (argc == 1){
		usage();
	}else{
		char cmd[128];
		strcpy (cmd,"diff");
		// Recompose la ligne de commande
		// Copie les options.
		for (int i=1; i<argc; i++){
			if (argv[i][0] == '-'){
				strcat (cmd," ");
				strcat (cmd,argv[i]);
			}else{
				break;
			}
		}
		USERINFO *user = userinfo_findenv (getenv("VCSID"));
		if (user != NULL){
			// Il y a maintenant 1 ou deux noms de fichier.
			char *fname1 = argv[i];
			if (argc - i == 2){
				char *fname2 = argv[i+1];
			}else if (argc - i == 1){
				if (file_exist(fname1)){
					char rpath[MAXSIZ_PATH];
					pdiff_rpath (fname1,rpath,user);
					strcat (cmd," ");
					strcat (cmd,fname1);
					strcat (cmd," ");
					strcat (cmd,rpath);
					printf ("# %s\n",cmd);
					ret = system (cmd);
				}else{
					fprintf (stderr,"Comparaison avec lui-mme\n");
				}
			}else{
				usage();
			}
		}else{
			// Pas dans un rpertoire avec archive
			// appelle diff avec les arguments sans traitement
		}
	}
	return ret;
}

==> linuxconf-tools-1.6.src.tar.gz: linuxconf-tools-1.6/projetx/pdiff.cc <==
/* Spcification: programme / pdiff

	pdiff permet d'appliquer la commande diff entre deux fichiers
	quelquoncques ou deux versions d'une mme fichier. Il localise
	les fichiers soit localement ou dans l'archive (/kit/ombre) et
	excute la commande diff avec les arguments corrigs.

	Comparaison entre la version locale et le rfrence:

		pdiff [options de diff] fichier

	Comparaison entre deux fichiers:

		pdiff [options de diff] fichier1 fichier2
*/
#include <stdio.h>
#include <assert.h>
#include <stdlib.h>
#include <string.h>
#include <misc.h>
#include "projet.h"

static void near usage()
{
	fprintf (stderr,"pdiff [options de diff] fichier1 fichier2\n");
	fprintf (stderr,"pdiff [options de diff] fichier\n");
}

/*
	Dtermine le path rel d'un fichier dans l'archive
*/
static void near pdiff_rpath (
	const char *fname,
	char *rpath,
	USERINFO *user)
{
	int ret = -1;
	MAKEFILE mkf ("makefile.dat",1,"",user);
	if (mkf.isok()){
		MAKEFILE_FILE *file = mkf.locate(fname);
		if (file != NULL){
			file->getombpath (user,rpath);
			ret = 0;
		}
	}
	if (ret == -1) exit (-1);
}


int main (int argc, char *argv[])
{
	int ret = -1;
	if (argc == 1){
		usage();
	}else{
		char cmd[128];
		strcpy (cmd,"diff");
		// Recompose la ligne de commande
		// Copie les options.
		for (int i=1; i<argc; i++){
			if (argv[i][0] == '-'){
				strcat (cmd," ");
				strcat (cmd,argv[i]);
			}else{
				break;
			}
		}
		USERINFO *user = userinfo_findenv (prog_getid(true));
		if (user != NULL){
			// Il y a maintenant 1 ou deux noms de fichier.
			char *fname1 = argv[i];
			if (argc - i == 2){
				char *fname2 = argv[i+1];
			}else if (argc - i == 1){
				if (file_exist(fname1)){
					char rpath[MAXSIZ_PATH];
					pdiff_rpath (fname1,rpath,user);
					strcat (cmd," ");
					strcat (cmd,fname1);
					strcat (cmd," ");
					strcat (cmd,rpath);
					printf ("# %s\n",cmd);
					ret = system (cmd);
				}else{
					fprintf (stderr,"Comparaison avec lui-mme\n");
				}
			}else{
				usage();
			}
		}else{
			// Pas dans un rpertoire avec archive
			// appelle diff avec les arguments sans traitement
		}
	}
	return ret;
}
